@@ -1,5 +1,5 @@
 /***************************************************************************
-                kdb.h  -  Exported methods of the Library
+      kdb.h  -  Exported methods of the Library
                              -------------------
     begin                : Mon Dec 29 2003
     copyright            : (C) 2003 by Avi Alkalay
@@ -7,6 +7,8 @@
     email                : avi@unix.sh, elektra@markus-raab.org
  ***************************************************************************/
 
+@DISCLAMER@
+
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -17,29 +19,22 @@
 #ifndef KDB_H
 #define KDB_H
 
-#include "kdbos.h"
+#include <kdbos.h>
 
-#define KDB_VERSION "0.7.1"
-#define KDB_VERSION_MAJOR 0
-#define KDB_VERSION_MINOR 7
-#define KDB_VERSION_MICRO 1
+#define KDB_VERSION "@KDB_VERSION@"
+#define KDB_VERSION_MAJOR @KDB_VERSION_MAJOR@
+#define KDB_VERSION_MINOR @KDB_VERSION_MINOR@
+#define KDB_VERSION_MICRO @KDB_VERSION_MICRO@
 
 #define KS_END ((Key*)0)
 
-enum {
-	KEY_TYPE_UNDEFINED=0,
-	KEY_TYPE_BINARY=20,
-	KEY_TYPE_STRING=40,
-	KEY_TYPE_MAX=256
-};
-
 enum {
 	KEY_END=0,
 	KEY_NAME=1,
 	KEY_VALUE=1<<1,
 	KEY_OWNER=1<<2,
 	KEY_COMMENT=1<<3,
-	KEY_TYPE=1<<4,
+	KEY_BINARY=1<<4,
 	KEY_UID=1<<5,
 	KEY_GID=1<<6,
 	KEY_MODE=1<<7,
@@ -47,9 +42,10 @@ enum {
 	KEY_MTIME=1<<9,
 	KEY_CTIME=1<<10,
 	KEY_SIZE=1<<11,
-	KEY_REMOVE=1<<12,
-	KEY_STAT=1<<13,
-	KEY_DIR=1<<14
+	KEY_FUNC=1<<12,
+	KEY_DIR=1<<14,
+	KEY_META=1<<15,
+	KEY_NULL=1<<16
 };
 
 enum {
@@ -58,8 +54,6 @@ enum {
 	KDB_O_POP=1<<1,
 	KDB_O_NODIR=1<<2,
 	KDB_O_DIRONLY=1<<3,
-	KDB_O_NOSTAT=1<<4,
-	KDB_O_STATONLY=1<<5,
 	KDB_O_NOREMOVE=1<<6,
 	KDB_O_REMOVEONLY=1<<7,
 	KDB_O_INACTIVE=1<<8,
@@ -89,24 +83,14 @@ typedef struct _KeySet	KeySet;
  *
  **************************************/
 
-KDB * kdbOpen(void);
-int kdbClose(KDB *handle);
+KDB * kdbOpen(Key *errorKey);
+int kdbClose(KDB *handle, Key *errorKey);
 
-ssize_t kdbGet(KDB *handle, KeySet *returned,
-	Key * parentKey, option_t options);
-ssize_t kdbSet(KDB *handle, KeySet *returned,
-	Key * parentKey, option_t options);
+int kdbGet(KDB *handle, KeySet *returned,
+	Key * parentKey);
+int kdbSet(KDB *handle, KeySet *returned,
+	Key * parentKey);
 
-ssize_t kdbGetByName(KDB *handle, KeySet *returned,
-	const char *parentName, option_t options);
-
-int kdbGetKey(KDB *handle, Key *key);
-int kdbSetKey(KDB *handle, const Key *key);
-
-int kdbGetString(KDB *handle, const char *keyname, char *returned,
-	size_t maxSize);
-int kdbSetString(KDB *handle, const char *keyname, const char *value);
-int kdbRemove(KDB *handle, const char *keyname);
 
 
 /**************************************
@@ -122,6 +106,7 @@ Key *keyVNew(const char *keyname, va_list ap);
 Key *keyDup(const Key *source);
 int keyCopy(Key *dest, const Key *source);
 
+int keyClear(Key *key);
 int keyDel(Key *key);
 
 ssize_t keyIncRef(Key *key);
@@ -129,45 +114,30 @@ ssize_t keyDecRef(Key *key);
 ssize_t keyGetRef(const Key *key);
 
 /* Meta Info */
-int keyStat(Key *key);
-int keyRemove(Key *key);
+int keyRewindMeta(Key *key);
+const Key *keyNextMeta(Key *key);
+const Key *keyCurrentMeta(const Key *key);
 
-uid_t keyGetUID(const Key *key);
-int keySetUID(Key *key, uid_t uid);
+int keyCopyMeta(Key *dest, const Key *source, const char *metaName);
+int keyCopyAllMeta(Key *dest, const Key *source);
 
-gid_t keyGetGID(const Key *key);
-int keySetGID(Key *key, gid_t gid);
+const Key *keyGetMeta(const Key *key, const char* metaName);
+ssize_t    keySetMeta(Key *key, const char* metaName,
+	const char *newMetaString);
 
-int keySetDir(Key *key);
-mode_t keyGetMode(const Key *key);
-int keySetMode(Key *key, mode_t mode);
-
-type_t keyGetType(const Key *key);
-int keySetType(Key *key, type_t type);
-
-time_t keyGetATime(const Key *key);
-int keySetATime(Key *key, time_t atime);
-
-time_t keyGetMTime(const Key *key);
-int keySetMTime(Key *key, time_t mtime);
-
-time_t keyGetCTime(const Key *key);
-int keySetCTime(Key *key, time_t ctime);
 
 /* Methods for Making Tests */
-int keyNeedStat(const Key *key);
-int keyNeedSync(const Key *key);
-int keyNeedRemove(const Key *key);
+int keyCmp(const Key *k1, const Key *k2);
+int keyRel (const Key *k1, const Key *k2);
 
-int keyIsSystem(const Key *key);
-int keyIsUser(const Key *key);
+int keyNeedSync(const Key *key);
 
 int keyIsBelow(const Key *key, const Key *check);
+int keyIsBelowOrSame(const Key *key, const Key *check);
 int keyIsDirectBelow(const Key *key, const Key *check);
 
 int keyIsInactive(const Key *key);
 
-int keyIsDir(const Key *key);
 int keyIsBinary(const Key *key);
 int keyIsString(const Key *key);
 
@@ -186,26 +156,17 @@ ssize_t keyGetBaseName(const Key *key, char *returned, size_t maxSize);
 ssize_t keyAddBaseName(Key *key,const char *baseName);
 ssize_t keySetBaseName(Key *key,const char *baseName);
 
-const char *keyOwner(const Key *key);
-ssize_t keyGetOwnerSize(const Key *key);
-ssize_t keyGetOwner(const Key *key, char *returned, size_t maxSize);
-ssize_t keySetOwner(Key *key, const char *owner);
-
 /* Value Manipulation Methods */
 const void *keyValue(const Key *key);
 ssize_t keyGetValueSize(const Key *key);
 
+const char *keyString(const Key *key);
 ssize_t keyGetString(const Key *key, char *returnedString, size_t maxSize);
 ssize_t keySetString(Key *key, const char *newString);
 
 ssize_t keyGetBinary(const Key *key, void *returnedBinary, size_t maxSize);
 ssize_t keySetBinary(Key *key, const void *newBinary, size_t dataSize);
 
-const char *keyComment(const Key *key);
-ssize_t keyGetCommentSize(const Key *key);
-ssize_t keyGetComment(const Key *key, char *returnedDesc, size_t maxSize);
-ssize_t keySetComment(Key *key, const char *newDesc);
-
 
 
 /**************************************
@@ -220,14 +181,19 @@ KeySet *ksVNew(size_t alloc, va_list ap);
 KeySet *ksDup(const KeySet * source);
 int ksCopy(KeySet *dest, const KeySet *source);
 
+int ksClear(KeySet *ks);
 int ksDel(KeySet *ks);
 
 void ksSort(KeySet *ks);
 
+int ksNeedSync(const KeySet *ks);
+
 ssize_t ksGetSize(const KeySet *ks);
 
 ssize_t ksAppendKey(KeySet *ks, Key *toAppend);
+
 ssize_t ksAppend(KeySet *ks, const KeySet *toAppend);
+KeySet *ksCut(KeySet *ks, const Key *cutpoint);
 
 Key *ksPop(KeySet *ks);
 
