@@ -17,38 +17,36 @@
  * .. means don't care, just enough for your system
  * For more information on that types read POSIX documentation.
  *
- * Type     Purpose                 Limits
- * size_t   size of array or string 0, SIZE_MAX
- * ssize_t  size with error cond.   -1, SSIZE_MAX(<SIZE_MAX)
- * time_t   Seconds since 1970      0,.. recommended: 64 bit
  *
  * Integer Types must be at least 32bit:
  *
+ * Type     Purpose                 Limits
  * int      Integral Fast Type      INT_MIN, INT_MAX
+ * size_t   size of array or string 0, SIZE_MAX
+ * ssize_t  size with error cond.   -1, SSIZE_MAX(<SIZE_MAX)
+ * time_t   Seconds since 1970      0,.. recommended: 64 bit
  * uid_t    User identification     0,..
  * gid_t    Group identification    0,..
- * keyswitch_t For keyNew
- * option_t    For kdbGet, kdbSet and ksLookup*
  *
  *
- * Following elektra specific types are defined:
+ * Following Elektra specific types must be defined with at least 32 bit:
  *
  * Type     Purpose
+ * keyswitch_t For keyNew
+ * option_t    For kdbGet, kdbSet and ksLookup*
  * cursor_t stores information to find a position in a keyset
  *
  * Following constants must be defined:
  *
- * KEY_SEPARATOR   how to delimit keynames
- * PATH_SEPARATOR  how to delimit pathnames
- * KEY_DEF_MODE    the standard mode for keys
- * KEY_DIR_MODE    the mode to add (|=) for key directories
+ * KDB_PATH_SEPARATOR  how to delimit pathnames
+ * KDB_FILE_MODE       the standard mode for keys
+ * KDB_DIR_MODE        the mode to add (|=) for key directories
+ * KDB_MAX_UCHAR       the maximum value of unsigned char
  *
  * Following limits must be defined (in addition to limits mentioned
  * above for types):
  *
- * MAX_UCHAR       the maximum for unsigned char
- * MAX_KEY_LENGTH  the maximum length for a keyname
- * MAX_PATH_LENGTH the maximum length for a pathname
+ * KDB_MAX_PATH_LENGTH the maximum length for a pathname
  *
  * In addition to the types the ... or va_list must be supported,
  * this is ISO C and should happen by including <stdarg.h>.
@@ -62,9 +60,6 @@
 #define KDBOS_H
 
 
-/* Include essential headers used in kdb.h */
-#include <stdarg.h>
-
 #ifndef WIN32
 
 /***************************************************
@@ -81,44 +76,29 @@
 #include <inttypes.h>
 #include <sys/types.h>
 
-/**Separator for Path names*/
-#define PATH_SEPARATOR '/'
 
-
-/**MAX_PATH_LENGTH will be the value for longest
+/**KDB_MAX_PATH_LENGTH will be the value for longest
  * possible filenames on the system.*/
 
 /*Some systems have even longer pathnames*/
 #ifdef PATH_MAX
-#define MAX_PATH_LENGTH PATH_MAX
+#define KDB_MAX_PATH_LENGTH PATH_MAX
 /*This value is garanteed on any Posixsystem*/
 #elif defined __USE_POSIX
-#define MAX_PATH_LENGTH _POSIX_PATH_MAX
+#define KDB_MAX_PATH_LENGTH _POSIX_PATH_MAX
 #else
-#define MAX_PATH_LENGTH 4096
+#define KDB_MAX_PATH_LENGTH 4096
 #endif
 
-/*Type to point to every position within the keyset*/
-typedef ssize_t cursor_t;
-
-/*Integer types*/
-typedef int keyswitch_t;
-typedef int option_t;
-
-/**Separator for key names.
- * This character will be used to separate key names*/
-#define KEY_SEPARATOR '/'
 /**Default Mode.
- * This mode will be used for fresh keys*/
-#define KEY_DEF_MODE 0664
+ * This mode will be used for new files*/
+#define KDB_FILE_MODE 0664
+
 /**Default directory mode.
- * This mode will be ORed to have a directory key*/
-#define KEY_DEF_DIR 0111
-
-/**Lets assume that the namespace + relative path is shorter then the absolute path.
- * So the maximum length of key is what the system allows for the path.*/
-#define MAX_KEY_LENGTH MAX_PATH_LENGTH
-
+ * This mode will be used for new directories.
+ * Will be ORed together with KDB_FILE_MODE
+ * to get the permissions of an directory.*/
+#define KDB_DIR_MODE 0111
 
 
 
@@ -127,20 +107,34 @@ typedef int option_t;
 /***************************************************
  *                 Windows
  ***************************************************/
+
+/* Avoid the most crazy things */
+#define NOMINMAX
+
 # include <windows.h>
 # include <limits.h>
 
 # define usleep(x) Sleep(x)
-
 # define ssize_t int
 # define snprintf _snprintf
 
-/**Separator for Path names*/
-#define PATH_SEPARATOR '\\'
+#define KDB_MAX_PATH_LENGTH 4096
 
-#define MAX_PATH_LENGTH 4096
 
-/*Type to point to every position within the keyset*/
+
+#endif /* WIN32 */
+
+/***************************************************
+ *               For ANSI C systems
+ ***************************************************/
+
+
+/* Include essential headers used in kdb.h */
+#include <stdarg.h>
+
+/*Type to point to every position within the keyset
+ * (note that for windows ssize_t is already redefined
+ * as int) */
 typedef ssize_t cursor_t;
 
 /*Integer types*/
@@ -149,25 +143,10 @@ typedef int option_t;
 
 /**Separator for key names.
  * This character will be used to separate key names*/
-#define KEY_SEPARATOR '/'
-/**Default Mode.
- * This mode will be used for fresh keys*/
-#define KEY_DEF_MODE 0664
-/**Default directory mode.
- * This mode will be ORed to have a directory key*/
-#define KEY_DEF_DIR 0111
+#define KDB_PATH_SEPARATOR '/'
 
-/**Lets assume that the namespace + relative path is shorter then the absolute path.
- * So the maximum length of key is what the system allows for the path.*/
-#define MAX_KEY_LENGTH MAX_PATH_LENGTH
+#define KDB_MAX_UCHAR (UCHAR_MAX+1)
 
 
 
-
-#endif /* WIN32 */
-
-#define KDB_FILE_MODE KEY_DEF_MODE
-#define KDB_DIR_MODE 0775
-
 #endif /* KDBOS_H */
-
