@@ -1,6 +1,8 @@
 #include <get.hpp>
 
 #include <kdb.hpp>
+#include <cmdline.hpp>
+#include <print.hpp>
 
 #include <iostream>
 
@@ -30,7 +32,12 @@ int GetCommand::execute (Cmdline const& cl)
 		return 1;
 	}
 
-	cout << k.getString() << endl;
+	cout << k.getString();
+
+	if (!cl.noNewline)
+	{
+		cout << endl;
+	}
 
 	return 0;
 }
