@@ -2,6 +2,8 @@
 
 #include <kdb.hpp>
 #include <modules.hpp>
+#include <cmdline.hpp>
+#include <print.hpp>
 
 #include <iostream>
 #include <memory>
@@ -15,9 +17,9 @@ ImportCommand::ImportCommand()
 int ImportCommand::execute(Cmdline const& cl)
 {
 	size_t argc = cl.arguments.size();
-	if (argc != 1 && argc != 2)
+	if (argc != 1 && argc != 2 && argc != 3)
 	{
-		throw invalid_argument("need 1 or 2 arguments");
+		throw invalid_argument("need 1 to 3 arguments");
 	}
 
 	Key root (cl.arguments[0], KEY_END);
@@ -32,11 +34,21 @@ int ImportCommand::execute(Cmdline const& cl)
 	KeySet importedKeys;
 
 	string format = "dump";
-	if (argc == 2) format = cl.arguments[1];
+	if (argc > 1) format = cl.arguments[1];
+
+	string file = "/dev/stdin";
+	if (argc > 2 && cl.arguments[2] != "-") file = cl.arguments[2];
 
 	Modules modules;
 	auto_ptr<Plugin> plugin = modules.load(format);
-	plugin->unserialize(importedKeys);
+
+	Key errorKey;
+	errorKey.setString(file);
+
+	plugin->get(importedKeys, errorKey);
+
+	printError(errorKey);
+	printWarnings(errorKey);
 
 	if (cl.strategy == "cut")
 	{
