@@ -1,10 +1,12 @@
 #include <metaset.hpp>
 
-#include <kdb.hpp>
-
 #include <iostream>
 #include <string>
 
+#include <kdb.hpp>
+#include <cmdline.hpp>
+#include <print.hpp>
+
 using namespace std;
 using namespace kdb;
 
