@@ -1,6 +1,8 @@
 #include <set.hpp>
 
 #include <kdb.hpp>
+#include <cmdline.hpp>
+#include <print.hpp>
 
 #include <iostream>
 
@@ -40,9 +42,13 @@ int SetCommand::execute(Cmdline const& cl)
 	// otherwise the user might break
 	// the config
 	kdb.get(conf, k);
-	printWarnings(k);
 
 	Key key = conf.lookup(name);
+	if (cl.verbose)
+	{
+		cout << "Getting configuration emitted warnings:" << endl;
+		printWarnings(k);
+	}
 
 	if (!key)
 	{
@@ -74,6 +80,7 @@ int SetCommand::execute(Cmdline const& cl)
 	}
 	Key n;
 	kdb.set(conf, n);
+
 	printWarnings(n);
 
 	return 0;
