@@ -83,9 +83,9 @@
 
 
 
-#ifdef HAVE_KDBCONFIG_H
-#include "kdbconfig.h"
-#endif
+#include <kdb.h>
+#include <kdbconfig.h>
+#include <kdbprivate.h>
 
 #if HAVE_STDIO_H
 #include <stdio.h>
@@ -103,9 +103,10 @@
 #include <stdlib.h>
 #endif
 
+#ifdef HAVE_ERRNO_H
+#include <errno.h>
+#endif
 
-#include "kdb.h"
-#include "kdbprivate.h"
 
 /**Rewind the internal iterator to first meta data.
  *
@@ -547,11 +548,6 @@ ssize_t keySetMeta(Key *key, const char* metaName,
  *********************************************/
 
 
-/**The maximum of how many characters an integer
-  needs as decimal number.*/
-#define MAX_LEN_INT 31
-#include <errno.h>
-
 
 
 /**
@@ -742,7 +738,7 @@ int keySetGID(Key *key, gid_t gid)
  * - Mode 0400 will be translated to 0711
  * - Mode 0664 will be translated to 0775
  *
- * The macro KEY_DEF_DIR (defined to 0111) will be used for that.
+ * The macro KDB_DIR_MODE (defined to 0111) will be used for that.
  *
  * The executable bits show that child keys are allowed and listable. There
  * is no way to have child keys which are not listable for anyone, but it is
@@ -788,13 +784,13 @@ int keySetDir(Key *key)
  * Default is 0664 (octal) for keys and 0775 for directory keys
  * which used keySetDir().
  *
- * The defaults are defined with the macros KEY_DEF_MODE and KEY_DEF_DIR.
+ * The defaults are defined with the macros KDB_FILE_MODE and KDB_DIR_MODE.
  *
  * For more information about the mode permissions see @ref mode.
  *
  * @param key the key object to work with
  * @return mode permissions of the key
- * @return KEY_DEF_MODE as defaults
+ * @return KDB_FILE_MODE as defaults
  * @return (mode_t)-1 on NULL pointer
  * @see keySetMode()
  * @ingroup keymeta
@@ -848,7 +844,7 @@ cleanup:
  * Default is 0664 (octal) for keys and 0775 for directory keys
  * which used keySetDir().
  *
- * The defaults are defined with the macros KEY_DEF_MODE and KEY_DEF_DIR.
+ * The defaults are defined with the macros KDB_FILE_MODE and KDB_DIR_MODE.
  *
  * @note libelektra 0.7.0 only allows 0775 (directory keys) and
  * 0664 (other keys). More will be added later in a sense of the
