@@ -45,8 +45,8 @@
 
 
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
+#ifdef HAVE_KDBCONFIG_H
+#include "kdbconfig.h"
 #endif
 
 #if DEBUG && HAVE_STDIO_H
@@ -108,7 +108,6 @@ keyDel(key);
  *
  * keyValue() returns 0 in binary mode when there is no value. The reason is
  * @code
-int i=23;
 key=keyNew(0);
 keySetBinary(key, 0, 0);
 keyValue(key); // you would expect 0 here
@@ -116,6 +115,7 @@ keyValue(key); // you would expect 0 here
 keySetBinary(key,"", 1);
 keyValue(key); // you would expect "" (a pointer to '\0') here
 
+int i=23;
 keySetBinary(key, (void*)&i, 4);
 (int*)keyValue(key); // you would expect a pointer to (int)23 here
 keyDel(key);
@@ -149,7 +149,7 @@ while(current=ksNext(ks)) {
 			size,
 			keyComment(current));
 	} else {
-		size=kdbiStrLen((char *)keyValue(current));
+		size=elektraStrLen((char *)keyValue(current));
 		printf("Key %s has a value of size %d bytes. Value: %s\nComment: %s",
 			keyName(current),
 			size,
@@ -174,14 +174,45 @@ const void *keyValue(const Key *key)
 {
 	if (!key) return 0;
 
-	if (!key->data)
+	if (!key->data.v)
 	{
 		/*errno=KDB_ERR_NOKEY;*/
 		if (keyIsBinary(key)) return 0;
 		else return "";
 	}
 
-	return key->data;
+	return key->data.v;
+}
+
+
+/**
+ * Get the c-string representing the value.
+ *
+ * Will return (null) on null pointers.
+ * Will return (binary) on binary data not ended
+ * with a null byte.
+ *
+ * It is not checked if it is actually a string,
+ * only if it terminates for security reasons.
+ *
+ * @return the c-string of the value
+ * @param key the key object to get the string from
+ */
+const char *keyString(const Key *key)
+{
+	if (!key) return "(null)";
+
+	if (!key->data.c)
+	{
+		return "";
+	}
+
+	if (key->data.c[key->dataSize-1] != 0)
+	{
+		return "(binary)";
+	}
+
+	return key->data.c;
 }
 
 
@@ -224,7 +255,7 @@ ssize_t keyGetValueSize(const Key *key)
 {
 	if (!key) return -1;
 
-	if (!key->data)
+	if (!key->data.v)
 	{
 		/*errno=KDB_ERR_NODATA;*/
 		if (keyIsBinary(key)) return 0;
@@ -287,7 +318,7 @@ ssize_t keyGetString(const Key *key, char *returnedString, size_t maxSize)
 		return -1;
 	}
 
-	if (!key->data) {
+	if (!key->data.v) {
 		returnedString[0]=0;
 		return 1;
 	}
@@ -298,7 +329,7 @@ ssize_t keyGetString(const Key *key, char *returnedString, size_t maxSize)
 	}
 
 
-	strncpy(returnedString,key->data, maxSize);
+	strncpy(returnedString,key->data.c, maxSize);
 	return key->dataSize;
 }
 
@@ -333,9 +364,9 @@ ssize_t keySetString(Key *key, const char *newStringValue)
 	if (!key) return -1;
 
 	if (!newStringValue || newStringValue[0] == '\0') ret=keySetRaw(key,0,0);
-	else ret=keySetRaw(key,newStringValue,kdbiStrLen(newStringValue));
+	else ret=keySetRaw(key,newStringValue,elektraStrLen(newStringValue));
 
-	if (!keyIsString(key)) keySetType(key, KEY_TYPE_STRING);
+	keySetMeta (key, "binary", 0);
 
 	return ret;
 }
@@ -396,7 +427,7 @@ ssize_t keyGetBinary(const Key *key, void *returnedBinary, size_t maxSize)
 		return -1;
 	}
 
-	if (!key->data)
+	if (!key->data.v)
 	{
 		return 0;
 	}
@@ -408,7 +439,7 @@ ssize_t keyGetBinary(const Key *key, void *returnedBinary, size_t maxSize)
 	}
 
 
-	memcpy(returnedBinary,key->data,key->dataSize);
+	memcpy(returnedBinary,key->data.v,key->dataSize);
 	return key->dataSize;
 }
 
@@ -420,15 +451,15 @@ ssize_t keyGetBinary(const Key *key, void *returnedBinary, size_t maxSize)
  * A private copy of @p newBinary will allocated and saved inside @p key,
  * so the parameter can be deallocated after the call.
  *
- * The @c filesys backend, when used through a kdbSetKey(), will make the
- * value be kdbbEncoded into a human readable hex-digit text format.
+ * Binary values might be encoded in another way then string values
+ * depending on the plugin.
  *
  * Consider using a string key instead.
  *
  * When newBinary is a NULL pointer the binary will be freed and 0 will
  * be returned.
  *
- * @note When the type of the key is already a binary type it won't be changed.
+ * @note When the key is already binary the meta data won't be changed.
  *
  * @param key the object on which to set the value
  * @param newBinary is a pointer to any binary data or NULL to free the previous set data
@@ -447,12 +478,14 @@ ssize_t keySetBinary(Key *key, const void *newBinary, size_t dataSize)
 	ssize_t ret=0;
 
 	if (!key) return -1;
+
 	if (!dataSize && newBinary) return -1;
 	if (dataSize > SSIZE_MAX) return -1;
 
+	keySetMeta (key, "binary", "");
+
 	ret = keySetRaw(key,newBinary,dataSize);
 
-	if (!keyIsBinary(key)) keySetType(key, KEY_TYPE_BINARY);
 
 	return ret;
 }
@@ -466,16 +499,21 @@ ssize_t keySetBinary(Key *key, const void *newBinary, size_t dataSize)
  * @param key the key object to work with
  * @param newBinary array of bytes to set as the value
  * @param dataSize number bytes to use from newBinary, including the final NULL
- * @return The number of bytes actually set in internall buffer.
+ * @return The number of bytes actually set in internal buffer.
+ * @return 1 if it was a string which was deleted
+ * @return 0 if it was a binary which was deleted
  * @see keySetType(), keySetString(), keySetBinary()
  * @ingroup keyvalue
  */
 ssize_t keySetRaw(Key *key, const void *newBinary, size_t dataSize)
 {
+	if (!key) return -1;
+	if (key->flags & KEY_FLAG_RO) return -1;
+
 	if (!dataSize || !newBinary) {
-		if (key->data) {
-			free(key->data);
-			key->data=0;
+		if (key->data.v) {
+			free(key->data.v);
+			key->data.v=0;
 		}
 		key->dataSize = 0;
 		key->flags |= KEY_FLAG_SYNC;
@@ -484,18 +522,18 @@ ssize_t keySetRaw(Key *key, const void *newBinary, size_t dataSize)
 	}
 
 	key->dataSize=dataSize;
-	if (key->data) {
+	if (key->data.v) {
 		char *p=0;
-		p=realloc(key->data,key->dataSize);
+		p=realloc(key->data.v,key->dataSize);
 		if (NULL==p) return -1;
-		key->data=p;
+		key->data.v=p;
 	} else {
-		key->data=malloc(key->dataSize);
+		key->data.v=malloc(key->dataSize);
         }
 
-	if (!key->data) return -1;
+	if (!key->data.v) return -1;
 
-	memcpy(key->data,newBinary,key->dataSize);
+	memcpy(key->data.v,newBinary,key->dataSize);
 	key->flags |= KEY_FLAG_SYNC;
 	return keyGetValueSize (key);
 }
@@ -543,15 +581,18 @@ keyDel(key);
  */
 const char *keyComment(const Key *key)
 {
-	if (!key) return 0;
+	const char *comment;
 
-	if (!key->comment)
+	if (!key) return 0;
+	comment = keyValue(keyGetMeta(key, "comment"));
+
+	if (!comment)
 	{
 		/*errno=KDB_ERR_NOKEY;*/
 		return "";
 	}
 
-	return key->comment;
+	return comment;
 }
 
 
@@ -585,15 +626,18 @@ buffer = malloc (keyGetCommentSize (key));
  */
 ssize_t keyGetCommentSize(const Key *key)
 {
+	ssize_t size;
 	if (!key) return -1;
 
-	if (!key->comment)
+	size = keyGetValueSize(keyGetMeta(key, "comment"));
+
+	if (!size || size == -1)
 	{
 		/*errno=KDB_ERR_NODESC;*/
 		return 1;
 	}
 
-	return key->commentSize;
+	return size;
 }
 
 
@@ -626,26 +670,30 @@ ssize_t keyGetCommentSize(const Key *key)
  */
 ssize_t keyGetComment(const Key *key, char *returnedComment, size_t maxSize)
 {
+	const char *comment;
+	size_t commentSize;
 	if (!key) return -1;
 
 	if (!maxSize) return -1;
 	if (!returnedComment) return -1;
 	if (maxSize > SSIZE_MAX) return -1;
 
+	comment = keyValue(keyGetMeta(key, "comment"));
+	commentSize = keyGetValueSize(keyGetMeta(key, "comment"));
 
-	if (!key->comment)
+	if (!comment)
 	{
 		/*errno=KDB_ERR_NODESC;*/
 		returnedComment[0]=0;
 		return 1;
 	}
 
-	strncpy(returnedComment,key->comment,maxSize);
-	if (maxSize < key->commentSize) {
+	strncpy(returnedComment,comment,maxSize);
+	if (maxSize < commentSize) {
 		/*errno=KDB_ERR_TRUNC;*/
 		return -1;
 	}
-	return key->commentSize;
+	return commentSize;
 }
 
 
@@ -661,46 +709,20 @@ ssize_t keyGetComment(const Key *key, char *returnedComment, size_t maxSize)
  * @param key the key object to work with
  * @param newComment the comment, that can be freed after this call.
  * @return the number of bytes actually saved including final NULL
- * @return 1 when the comment was freed
+ * @return 0 when the comment was freed (newComment NULL or empty string)
  * @return -1 on NULL pointer or memory problems
  * @see keyGetComment()
  * @ingroup keyvalue
  */
 ssize_t keySetComment(Key *key, const char *newComment)
 {
-	ssize_t size=0;
-
 	if (!key) return -1;
-
-	if (newComment && (size=kdbiStrLen(newComment)) > 1)
+	if (!newComment || *newComment==0)
 	{
-		if (key->comment) {
-			char *p=0;
-			p=realloc(key->comment,size);
-			if (NULL==p) {
-				key->commentSize = 0;
-				/*errno=KDB_ERR_NOMEM;*/
-				return -1;
-			}
-			key->comment=p;
-		} else {
-			key->comment=malloc(size);
-			if (!key->comment) {
-				key->commentSize = 0;
-				/*errno=KDB_ERR_NOMEM;*/
-				return -1;
-			}
-		}
-
-		strcpy(key->comment,newComment);
-		key->flags |= KEY_FLAG_SYNC;
-		key->commentSize=size;
-	} else if (key->comment) {
-		free(key->comment);
-		key->comment=0;
-		key->commentSize=1;
-		key->flags |= KEY_FLAG_SYNC;
+		keySetMeta (key, "comment", 0);
+		return 1;
 	}
-	return key->commentSize;
-}
 
+	keySetMeta (key, "comment", newComment);
+	return keyGetCommentSize (key);
+}
