@@ -13,12 +13,7 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifdef HAVE_KDBCONFIG_H
-#include "kdbconfig.h"
-#endif
-
-#include <tests.h>
-
+#include <tests_internal.h>
 
 struct test {
 	char	*testName;
@@ -86,7 +81,12 @@ struct test tstKeyName[] =
 	
 	},
 	
-	{ NULL, NULL, NULL }
+	{ NULL, NULL,
+		NULL, /* keyName 	*/
+		NULL, /* keyBaseName 	*/
+		NULL, /* keyGetFullRootName 	*/ 
+		NULL  /* keyGetParentName	*/
+	}
 };
 
 void test_keyComparing()
@@ -239,7 +239,7 @@ void test_keyNewUser()
 {
 	Key     *key;
 	char array[] = "here is some data stored";
-	char fullroot [MAX_PATH_LENGTH];
+	char fullroot [KDB_MAX_PATH_LENGTH];
 	char * getBack;
 	Key *k1;
 	Key *k2;
@@ -251,7 +251,7 @@ void test_keyNewUser()
 	succeed_if (keySetOwner(key, "hugo") == sizeof("hugo"), "could not set owner");
 	succeed_if( strcmp(keyOwner(key), "hugo") == 0, "keyNew: owner not set correctly");
 	succeed_if( keyGetOwnerSize(key) == 5, "owner length not correct");
-	keyGetFullName (key, fullroot, MAX_PATH_LENGTH);
+	keyGetFullName (key, fullroot, KDB_MAX_PATH_LENGTH);
 	succeed_if( strcmp(keyOwner(key), "hugo") == 0, "keyNew: owner not set correctly");
 	/* printf ("%s, %s, %s\n", keyName(key), keyBaseName(key), fullroot); */
 	succeed_if(strcmp(keyName(key),"user/test/test") == 0, "Wrong keyname: keyName");
@@ -264,7 +264,7 @@ void test_keyNewUser()
 	succeed_if (keySetOwner(key, "tommy") == sizeof("tommy"), "could not set owner");
 	succeed_if( strcmp(keyOwner(key), "tommy") == 0, "keyNew: owner not set correctly");
 	succeed_if( keyGetOwnerSize(key) == 6, "owner length not correct");
-	keyGetFullName (key, fullroot, MAX_PATH_LENGTH);
+	keyGetFullName (key, fullroot, KDB_MAX_PATH_LENGTH);
 	succeed_if( strcmp(keyOwner(key), "tommy") == 0, "keyNew: owner not set correctly");
 	/* printf ("%s, %s, %s\n", keyName(key), keyBaseName(key), fullroot); */
 	succeed_if(strcmp(keyName(key),"user/test/test") == 0, "Wrong keyname: keyName");
@@ -905,7 +905,7 @@ void test_keyName()
 
 		succeed_if (keyGetRef (copy) == 0, "reference of copy not correct");
 		keyCopy (copy, key);
-		succeed_if (compare_key (copy, key) == 0, "keys are not equal after copy");
+		compare_key (copy, key);
 		succeed_if (keyGetRef (copy) == 0, "reference of copy not correct");
 
 		keyDel(key);
@@ -1570,7 +1570,7 @@ void test_keyCopy()
 	orig = keyNew(0);
 	succeed_if (keyCopy(copy, 0) == 0, "make the key copy fresh");
 
-	succeed_if (compare_key (orig, copy) == 0, "keyCopy did not make the key fresh");
+	compare_key (orig, copy);
 	keyDel (orig);
 
 	keyDel(copy);
@@ -1786,15 +1786,15 @@ void test_keyMeta(void)
 	keyDel (key);
 
 	key = keyNew(0);
-	succeed_if(keyGetMode(key) == KEY_DEF_MODE, "new key does not have default mode");
+	succeed_if(keyGetMode(key) == KDB_FILE_MODE, "new key does not have default mode");
 	succeed_if(keySetDir(key) == 0, "could not set dir");
-	succeed_if(keyGetMode(key) == (KEY_DEF_MODE | KEY_DEF_DIR), "directory key");
+	succeed_if(keyGetMode(key) == (KDB_FILE_MODE | KDB_DIR_MODE), "directory key");
 	keyDel (key);
 
 	key = keyNew("user/dir", KEY_DIR, KEY_END);
-	succeed_if(keyGetMode(key) == (KEY_DEF_MODE | KEY_DEF_DIR), "directory key");
+	succeed_if(keyGetMode(key) == (KDB_FILE_MODE | KDB_DIR_MODE), "directory key");
 	succeed_if(keySetDir(key) == 0, "could not set dir");
-	succeed_if(keyGetMode(key) == (KEY_DEF_MODE | KEY_DEF_DIR), "directory key");
+	succeed_if(keyGetMode(key) == (KDB_FILE_MODE | KDB_DIR_MODE), "directory key");
 	keyDel (key);
 }
 
